==> bittensor-5.3.1.tar.gz: bittensor-5.3.1/tests/unit_tests/bittensor_tests/test_metagraph.py <==
# The MIT License (MIT)
# Copyright © 2023 Opentensor Foundation

# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
# documentation files (the “Software”), to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all copies or substantial portions of
# the Software.

# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
# THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

import bittensor
import unittest

_subtensor_mock = bittensor.subtensor( network = 'mock', _mock = True )
    
class TestMetagraph(unittest.TestCase):
    def setUp(self) -> None:
        global _subtensor_mock
        _subtensor_mock.reset()

        _subtensor_mock.create_subnet(
            netuid = 999
        )

    def test_metagraph(self):
        global _subtensor_mock
        metagraph = _subtensor_mock.metagraph( netuid = 999 )

        assert metagraph.netuid == 999
        assert metagraph.n == 0
        assert len(metagraph.hotkeys) == 0
        assert len(metagraph.coldkeys) == 0
        assert len(metagraph.uids) == 0

==> bittensor-5.3.3.tar.gz: bittensor-5.3.3/tests/unit_tests/bittensor_tests/test_metagraph.py <==
# The MIT License (MIT)
# Copyright © 2023 Opentensor Foundation

# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
# documentation files (the “Software”), to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all copies or substantial portions of
# the Software.

# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO
# THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

import bittensor
import unittest

_subtensor_mock = bittensor.subtensor(network="mock", _mock=True)


class TestMetagraph(unittest.TestCase):
    def setUp(self) -> None:
        global _subtensor_mock
        _subtensor_mock.reset()

        _subtensor_mock.create_subnet(netuid=999)

    def test_metagraph(self):
        global _subtensor_mock
        metagraph = _subtensor_mock.metagraph(netuid=999)

        assert metagraph.netuid == 999
        assert metagraph.n == 0
        assert len(metagraph.hotkeys) == 0
        assert len(metagraph.coldkeys) == 0
        assert len(metagraph.uids) == 0
